xls2xlsx package
================

Submodules
----------

xls2xlsx.cli module
-------------------

.. automodule:: xls2xlsx.cli
   :members:
   :undoc-members:
   :show-inheritance:

xls2xlsx.htmlxls2xlsx module
----------------------------

.. automodule:: xls2xlsx.htmlxls2xlsx
   :members:
   :undoc-members:
   :show-inheritance:

xls2xlsx.utils module
---------------------

.. automodule:: xls2xlsx.utils
   :members:
   :undoc-members:
   :show-inheritance:

xls2xlsx.xls2xlsx module
------------------------

.. automodule:: xls2xlsx.xls2xlsx
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: xls2xlsx
   :members:
   :undoc-members:
   :show-inheritance:
